==> sanduhr_1.0.orig.tar.gz: sanduhr-1.0/src/callbacks.h <==
#include <gnome.h>


void
on_about2_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_custom_entry_changed                (GtkEditable     *editable,
                                        gpointer         user_data);

void
apply_settings                         (GnomePropertyBox *gnomepropertybox,
                                        gint             arg1,
                                        gpointer         user_data);

void
settings_changed                       (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_snd_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_cmd_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_settings_help                       (GnomePropertyBox *gnomepropertybox,
                                        gint             arg1,
                                        gpointer         user_data);

void
on_init_help_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_properties1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gint
on_settings_close                      (GnomeDialog     *gnomedialog,
                                        gpointer         user_data);

void
pref_changed                           (GtkWidget       *control,
                                        gpointer         user_data);

void
on_preferences_apply                   (GnomePropertyBox *gnomepropertybox,
                                        gint             arg1,
                                        gpointer         user_data);

void
on_preferences_help                    (GnomePropertyBox *gnomepropertybox,
                                        gint             arg1,
                                        gpointer         user_data);

void
on_pref_file_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_pref_cmd_changed                    (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_color_pref_color_set                (GnomeColorPicker *gnomecolorpicker,
                                        guint            arg1,
                                        guint            arg2,
                                        guint            arg3,
                                        guint            arg4,
                                        gpointer         user_data);

void
on_corba_entry_changed                 (GtkEditable     *editable,
                                        gpointer         user_data);

==> sanduhr_1.93.orig.tar.gz: sanduhr-1.93/src/callbacks.h <==
#include <gnome.h>


void
on_about2_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_custom_entry_changed                (GtkEditable     *editable,
                                        gpointer         user_data);

void
apply_settings                         (GnomePropertyBox *propertybox,
                                        gint             page_num,
                                        gpointer         user_data);

void
settings_changed                       (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_snd_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_cmd_entry_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_properties_help                     (GnomePropertyBox *propertybox,
                                        gint             page_num,
                                        gpointer         user_data);

void
on_init_help_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_properties1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_properties_close                    (GnomeDialog     *gnomedialog,
                                        gpointer         user_data);

void
pref_changed                           (GtkWidget       *w,
                                        gpointer         user_data);

void
on_preferences_apply                   (GnomePropertyBox *gnomepropertybox,
                                        gint             arg1,
                                        gpointer         user_data);

void
on_preferences_help                    (GnomePropertyBox *gnomepropertybox,
                                        gint             page_num,
                                        gpointer         user_data);

void
on_pref_file_changed                   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_pref_cmd_changed                    (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_color_pref_color_set                (GnomeColorPicker *gnomecolorpicker,
                                        guint            arg1,
                                        guint            arg2,
                                        guint            arg3,
                                        guint            arg4,
                                        gpointer         user_data);

void
on_corba_entry_changed                 (GtkEditable     *editable,
                                        gpointer         user_data);
